@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Homebrew for macOS
 
 .. important::
@@ -7,7 +7,7 @@ Homebrew for macOS
     minion, and it is using a different module (or gives an error similar to
     *'pkg.install' is not available*), see :ref:`here
     <module-provider-override>`.
-'''
+"""
 from __future__ import absolute_import, print_function, unicode_literals
 
 # Import python libs
@@ -23,7 +23,7 @@ import salt.utils.json
 import salt.utils.path
 import salt.utils.pkg
 import salt.utils.versions
-from salt.exceptions import CommandExecutionError, MinionError
+from salt.exceptions import CommandExecutionError, MinionError, SaltInvocationError
 
 # Import third party libs
 from salt.ext import six
@@ -32,36 +32,75 @@ from salt.ext.six.moves import zip
 log = logging.getLogger(__name__)
 
 # Define the module's virtual name
-__virtualname__ = 'pkg'
+__virtualname__ = "pkg"
 
 
 def __virtual__():
-    '''
+    """
     Confine this module to Mac OS with Homebrew.
-    '''
+    """
 
-    if salt.utils.path.which('brew') and __grains__['os'] == 'MacOS':
+    if salt.utils.path.which("brew") and __grains__["os"] == "MacOS":
         return __virtualname__
-    return (False, 'The brew module could not be loaded: brew not found or grain os != MacOS')
+    return (
+        False,
+        "The brew module could not be loaded: brew not found or grain os != MacOS",
+    )
 
 
 def _list_taps():
-    '''
+    """
     List currently installed brew taps
-    '''
-    cmd = 'tap'
-    return _call_brew(cmd)['stdout'].splitlines()
+    """
+    cmd = "tap"
+    return _call_brew(cmd)["stdout"].splitlines()
+
+
+def _list_pinned():
+    """
+    List currently pinned formulas
+    """
+    cmd = "list --pinned"
+    return _call_brew(cmd)["stdout"].splitlines()
+
+
+def _pin(pkg, runas=None):
+    """
+    Pin pkg
+    """
+    cmd = "pin {0}".format(pkg)
+    try:
+        _call_brew(cmd)
+    except CommandExecutionError:
+        log.error('Failed to pin "%s"', pkg)
+        return False
+
+    return True
+
+
+def _unpin(pkg, runas=None):
+    """
+    Pin pkg
+    """
+    cmd = "unpin {0}".format(pkg)
+    try:
+        _call_brew(cmd)
+    except CommandExecutionError:
+        log.error('Failed to unpin "%s"', pkg)
+        return False
+
+    return True
 
 
 def _tap(tap, runas=None):
-    '''
+    """
     Add unofficial GitHub repos to the list of formulas that brew tracks,
     updates, and installs from.
-    '''
+    """
     if tap in _list_taps():
         return True
 
-    cmd = 'tap {0}'.format(tap)
+    cmd = "tap {0}".format(tap)
     try:
         _call_brew(cmd)
     except CommandExecutionError:
@@ -72,33 +111,31 @@ def _tap(tap, runas=None):
 
 
 def _homebrew_bin():
-    '''
+    """
     Returns the full path to the homebrew binary in the PATH
-    '''
-    ret = __salt__['cmd.run']('brew --prefix', output_loglevel='trace')
-    ret += '/bin/brew'
+    """
+    ret = __salt__["cmd.run"]("brew --prefix", output_loglevel="trace")
+    ret += "/bin/brew"
     return ret
 
 
 def _call_brew(cmd, failhard=True):
-    '''
+    """
     Calls the brew command with the user account of brew
-    '''
-    user = __salt__['file.get_user'](_homebrew_bin())
-    runas = user if user != __opts__['user'] else None
-    cmd = '{} {}'.format(salt.utils.path.which('brew'), cmd)
-    result = __salt__['cmd.run_all'](cmd,
-                                     runas=runas,
-                                     output_loglevel='trace',
-                                     python_shell=False)
-    if failhard and result['retcode'] != 0:
-        raise CommandExecutionError('Brew command failed',
-                                    info={'result': result})
+    """
+    user = __salt__["file.get_user"](_homebrew_bin())
+    runas = user if user != __opts__["user"] else None
+    cmd = "{} {}".format(salt.utils.path.which("brew"), cmd)
+    result = __salt__["cmd.run_all"](
+        cmd, runas=runas, output_loglevel="trace", python_shell=False
+    )
+    if failhard and result["retcode"] != 0:
+        raise CommandExecutionError("Brew command failed", info={"result": result})
     return result
 
 
 def list_pkgs(versions_as_list=False, **kwargs):
-    '''
+    """
     List the packages currently installed in a dict::
 
         {'<package_name>': '<version>'}
@@ -108,79 +145,84 @@ def list_pkgs(versions_as_list=False, **kwargs):
     .. code-block:: bash
 
         salt '*' pkg.list_pkgs
-    '''
+    """
     versions_as_list = salt.utils.data.is_true(versions_as_list)
     # not yet implemented or not applicable
-    if any([salt.utils.data.is_true(kwargs.get(x))
-            for x in ('removed', 'purge_desired')]):
+    if any(
+        [salt.utils.data.is_true(kwargs.get(x)) for x in ("removed", "purge_desired")]
+    ):
         return {}
 
-    if 'pkg.list_pkgs' in __context__:
+    if "pkg.list_pkgs" in __context__:
         if versions_as_list:
-            return __context__['pkg.list_pkgs']
+            return __context__["pkg.list_pkgs"]
         else:
-            ret = copy.deepcopy(__context__['pkg.list_pkgs'])
-            __salt__['pkg_resource.stringify'](ret)
+            ret = copy.deepcopy(__context__["pkg.list_pkgs"])
+            __salt__["pkg_resource.stringify"](ret)
             return ret
 
     ret = {}
-    cmd = 'info --json=v1 --installed'
-    package_info = salt.utils.json.loads(_call_brew(cmd)['stdout'])
+    cmd = "info --json=v1 --installed"
+    package_info = salt.utils.json.loads(_call_brew(cmd)["stdout"])
 
     for package in package_info:
         # Brew allows multiple versions of the same package to be installed.
         # Salt allows for this, so it must be accounted for.
-        versions = [v['version'] for v in package['installed']]
+        versions = [v["version"] for v in package["installed"]]
         # Brew allows for aliasing of packages, all of which will be
         # installable from a Salt call, so all names must be accounted for.
-        names = package['aliases'] + [package['name'], package['full_name']]
+        names = package["aliases"] + [package["name"], package["full_name"]]
         # Create a list of tuples containing all possible combinations of
         # names and versions, because all are valid.
         combinations = [(n, v) for n in names for v in versions]
 
         for name, version in combinations:
-            __salt__['pkg_resource.add_pkg'](ret, name, version)
+            __salt__["pkg_resource.add_pkg"](ret, name, version)
 
     # Grab packages from brew cask, if available.
     # Brew Cask doesn't provide a JSON interface, must be parsed the old way.
     try:
-        cask_cmd = 'cask list --versions'
-        out = _call_brew(cask_cmd)['stdout']
+        cask_cmd = "cask list --versions"
+        out = _call_brew(cask_cmd)["stdout"]
 
         for line in out.splitlines():
             try:
-                name_and_versions = line.split(' ')
+                name_and_versions = line.split(" ")
                 pkg_name = name_and_versions[0]
 
                 # Get cask namespace
-                info_cmd = 'cask info {}'.format(pkg_name)
-                match = re.search(r'^From: .*/(.+?)/homebrew-(.+?)/.*$',
-                                  _call_brew(info_cmd)['stdout'], re.MULTILINE)
+                info_cmd = "cask info {}".format(pkg_name)
+                match = re.search(
+                    r"^From: .*/(.+?)/homebrew-(.+?)/.*$",
+                    _call_brew(info_cmd)["stdout"],
+                    re.MULTILINE,
+                )
                 if match:
-                    namespace = '/'.join((match.group(1).lower(),
-                                          match.group(2).lower()))
+                    namespace = "/".join(
+                        (match.group(1).lower(), match.group(2).lower())
+                    )
                 else:
-                    namespace = 'homebrew/cask'
+                    namespace = "homebrew/cask"
 
-                name = '/'.join((namespace, pkg_name))
+                name = "/".join((namespace, pkg_name))
                 installed_versions = name_and_versions[1:]
                 key_func = functools.cmp_to_key(salt.utils.versions.version_cmp)
                 newest_version = sorted(installed_versions, key=key_func).pop()
             except ValueError:
                 continue
-            __salt__['pkg_resource.add_pkg'](ret, name, newest_version)
+            __salt__["pkg_resource.add_pkg"](ret, name, newest_version)
     except CommandExecutionError:
         pass
 
-    __salt__['pkg_resource.sort_pkglist'](ret)
-    __context__['pkg.list_pkgs'] = copy.deepcopy(ret)
+    __salt__["pkg_resource.sort_pkglist"](ret)
+    __context__["pkg.list_pkgs"] = copy.deepcopy(ret)
     if not versions_as_list:
-        __salt__['pkg_resource.stringify'](ret)
+        __salt__["pkg_resource.stringify"](ret)
     return ret
 
 
 def version(*names, **kwargs):
-    '''
+    """
     Returns a string representing the package version or an empty string if not
     installed. If more than one package name is specified, a dict of
     name/version pairs is returned.
@@ -191,12 +233,12 @@ def version(*names, **kwargs):
 
         salt '*' pkg.version <package name>
         salt '*' pkg.version <package1> <package2> <package3>
-    '''
-    return __salt__['pkg_resource.version'](*names, **kwargs)
+    """
+    return __salt__["pkg_resource.version"](*names, **kwargs)
 
 
 def latest_version(*names, **kwargs):
-    '''
+    """
     Return the latest version of the named package available for upgrade or
     installation
 
@@ -209,16 +251,18 @@ def latest_version(*names, **kwargs):
 
         salt '*' pkg.latest_version <package name>
         salt '*' pkg.latest_version <package1> <package2> <package3>
-    '''
-    refresh = salt.utils.data.is_true(kwargs.pop('refresh', True))
+    """
+    refresh = salt.utils.data.is_true(kwargs.pop("refresh", True))
     if refresh:
         refresh_db()
 
     def get_version(pkg_info):
         # Perhaps this will need an option to pick devel by default
-        return pkg_info['versions']['stable'] or pkg_info['versions']['devel']
+        return pkg_info["versions"]["stable"] or pkg_info["versions"]["devel"]
 
-    versions_dict = dict((key, get_version(val)) for key, val in six.iteritems(_info(*names)))
+    versions_dict = dict(
+        (key, get_version(val)) for key, val in six.iteritems(_info(*names))
+    )
 
     if len(names) == 1:
         return next(six.itervalues(versions_dict))
@@ -227,11 +271,13 @@ def latest_version(*names, **kwargs):
 
 
 # available_version is being deprecated
-available_version = salt.utils.functools.alias_function(latest_version, 'available_version')
+available_version = salt.utils.functools.alias_function(
+    latest_version, "available_version"
+)
 
 
 def remove(name=None, pkgs=None, **kwargs):
-    '''
+    """
     Removes packages with ``brew uninstall``.
 
     name
@@ -256,12 +302,9 @@ def remove(name=None, pkgs=None, **kwargs):
         salt '*' pkg.remove <package name>
         salt '*' pkg.remove <package1>,<package2>,<package3>
         salt '*' pkg.remove pkgs='["foo", "bar"]'
-    '''
+    """
     try:
-        name, pkgs = _fix_cask_namespace(name, pkgs)
-        pkg_params = __salt__['pkg_resource.parse_targets'](
-            name, pkgs, **kwargs
-        )[0]
+        pkg_params = __salt__["pkg_resource.parse_targets"](name, pkgs, **kwargs)[0]
     except MinionError as exc:
         raise CommandExecutionError(exc)
 
@@ -269,29 +312,29 @@ def remove(name=None, pkgs=None, **kwargs):
     targets = [x for x in pkg_params if x in old]
     if not targets:
         return {}
-    cmd = 'uninstall {0}'.format(' '.join(targets))
+    cmd = "uninstall {0}".format(" ".join(targets))
 
     out = _call_brew(cmd)
-    if out['retcode'] != 0 and out['stderr']:
-        errors = [out['stderr']]
+    if out["retcode"] != 0 and out["stderr"]:
+        errors = [out["stderr"]]
     else:
         errors = []
 
-    __context__.pop('pkg.list_pkgs', None)
+    __context__.pop("pkg.list_pkgs", None)
     new = list_pkgs()
     ret = salt.utils.data.compare_dicts(old, new)
 
     if errors:
         raise CommandExecutionError(
-            'Problem encountered removing package(s)',
-            info={'errors': errors, 'changes': ret}
+            "Problem encountered removing package(s)",
+            info={"errors": errors, "changes": ret},
         )
 
     return ret
 
 
-def refresh_db():
-    '''
+def refresh_db(**kwargs):
+    """
     Update the homebrew package repository.
 
     CLI Example:
@@ -299,19 +342,19 @@ def refresh_db():
     .. code-block:: bash
 
         salt '*' pkg.refresh_db
-    '''
+    """
     # Remove rtag file to keep multiple refreshes from happening in pkg states
     salt.utils.pkg.clear_rtag(__opts__)
-    cmd = 'update'
-    if _call_brew(cmd)['retcode']:
-        log.error('Failed to update')
+    cmd = "update"
+    if _call_brew(cmd)["retcode"]:
+        log.error("Failed to update")
         return False
 
     return True
 
 
 def _info(*pkgs):
-    '''
+    """
     Get all info brew can provide about a list of packages.
 
     Does not do any kind of processing, so the format depends entirely on
@@ -324,19 +367,18 @@ def _info(*pkgs):
 
     Caveat: If one of the packages does not exist, no packages will be
             included in the output.
-    '''
-    cmd = 'info --json=v1 {0}'.format(' '.join(pkgs))
+    """
+    cmd = "info --json=v1 {0}".format(" ".join(pkgs))
     brew_result = _call_brew(cmd)
-    if brew_result['retcode']:
-        log.error('Failed to get info about packages: %s',
-                  ' '.join(pkgs))
+    if brew_result["retcode"]:
+        log.error("Failed to get info about packages: %s", " ".join(pkgs))
         return {}
-    output = salt.utils.json.loads(brew_result['stdout'])
+    output = salt.utils.json.loads(brew_result["stdout"])
     return dict(zip(pkgs, output))
 
 
 def install(name=None, pkgs=None, taps=None, options=None, **kwargs):
-    '''
+    """
     Install the passed package(s) with ``brew install``
 
     name
@@ -396,19 +438,18 @@ def install(name=None, pkgs=None, taps=None, options=None, **kwargs):
     .. code-block:: bash
 
         salt '*' pkg.install 'package package package'
-    '''
+    """
     try:
-        name, pkgs = _fix_cask_namespace(name, pkgs)
-        pkg_params, pkg_type = __salt__['pkg_resource.parse_targets'](
-            name, pkgs, kwargs.get('sources', {})
+        pkg_params, pkg_type = __salt__["pkg_resource.parse_targets"](
+            name, pkgs, kwargs.get("sources", {})
         )
     except MinionError as exc:
         raise CommandExecutionError(exc)
 
-    if pkg_params is None or len(pkg_params) == 0:
+    if not pkg_params:
         return {}
 
-    formulas = ' '.join(pkg_params)
+    formulas = " ".join(pkg_params)
     old = list_pkgs()
 
     # Ensure we've tapped the repo if necessary
@@ -422,31 +463,31 @@ def install(name=None, pkgs=None, taps=None, options=None, **kwargs):
             _tap(tap)
 
     if options:
-        cmd = 'install {0} {1}'.format(formulas, ' '.join(options))
+        cmd = "install {0} {1}".format(formulas, " ".join(options))
     else:
-        cmd = 'install {0}'.format(formulas)
+        cmd = "install {0}".format(formulas)
 
     out = _call_brew(cmd)
-    if out['retcode'] != 0 and out['stderr']:
-        errors = [out['stderr']]
+    if out["retcode"] != 0 and out["stderr"]:
+        errors = [out["stderr"]]
     else:
         errors = []
 
-    __context__.pop('pkg.list_pkgs', None)
+    __context__.pop("pkg.list_pkgs", None)
     new = list_pkgs()
     ret = salt.utils.data.compare_dicts(old, new)
 
     if errors:
         raise CommandExecutionError(
-            'Problem encountered installing package(s)',
-            info={'errors': errors, 'changes': ret}
+            "Problem encountered installing package(s)",
+            info={"errors": errors, "changes": ret},
         )
 
     return ret
 
 
 def list_upgrades(refresh=True, **kwargs):  # pylint: disable=W0613
-    '''
+    """
     Check whether or not an upgrade is available for all packages
 
     CLI Example:
@@ -454,15 +495,15 @@ def list_upgrades(refresh=True, **kwargs):  # pylint: disable=W0613
     .. code-block:: bash
 
         salt '*' pkg.list_upgrades
-    '''
+    """
     if refresh:
         refresh_db()
 
-    res = _call_brew('outdated --json=v1')
+    res = _call_brew("outdated --json=v1")
     ret = {}
 
     try:
-        data = salt.utils.json.loads(res['stdout'])
+        data = salt.utils.json.loads(res["stdout"])
     except ValueError as err:
         msg = 'unable to interpret output from "brew outdated": {0}'.format(err)
         log.error(msg)
@@ -470,12 +511,12 @@ def list_upgrades(refresh=True, **kwargs):  # pylint: disable=W0613
 
     for pkg in data:
         # current means latest available to brew
-        ret[pkg['name']] = pkg['current_version']
+        ret[pkg["name"]] = pkg["current_version"]
     return ret
 
 
-def upgrade_available(pkg):
-    '''
+def upgrade_available(pkg, **kwargs):
+    """
     Check whether or not an upgrade is available for a given package
 
     CLI Example:
@@ -483,12 +524,12 @@ def upgrade_available(pkg):
     .. code-block:: bash
 
         salt '*' pkg.upgrade_available <package name>
-    '''
+    """
     return pkg in list_upgrades()
 
 
-def upgrade(refresh=True):
-    '''
+def upgrade(refresh=True, **kwargs):
+    """
     Upgrade outdated, unpinned brews.
 
     refresh
@@ -507,33 +548,34 @@ def upgrade(refresh=True):
     .. code-block:: bash
 
         salt '*' pkg.upgrade
-    '''
-    ret = {'changes': {},
-           'result': True,
-           'comment': '',
-           }
+    """
+    ret = {
+        "changes": {},
+        "result": True,
+        "comment": "",
+    }
 
     old = list_pkgs()
 
     if salt.utils.data.is_true(refresh):
         refresh_db()
 
-    result = _call_brew('upgrade', failhard=False)
-    __context__.pop('pkg.list_pkgs', None)
+    result = _call_brew("upgrade", failhard=False)
+    __context__.pop("pkg.list_pkgs", None)
     new = list_pkgs()
     ret = salt.utils.data.compare_dicts(old, new)
 
-    if result['retcode'] != 0:
+    if result["retcode"] != 0:
         raise CommandExecutionError(
-            'Problem encountered upgrading packages',
-            info={'changes': ret, 'result': result}
+            "Problem encountered upgrading packages",
+            info={"changes": ret, "result": result},
         )
 
     return ret
 
 
-def info_installed(*names):
-    '''
+def info_installed(*names, **kwargs):
+    """
     Return the information of the named package(s) installed on the system.
 
     .. versionadded:: 2016.3.1
@@ -547,7 +589,7 @@ def info_installed(*names):
 
         salt '*' pkg.info_installed <package1>
         salt '*' pkg.info_installed <package1> <package2> <package3> ...
-    '''
+    """
     return _info(*names)
 
 
@@ -557,7 +599,7 @@ def _fix_cask_namespace(name=None, pkgs=None):
     and replace it by the new one.
 
     This function also warns about the correct namespace for this packages
-    and it will stop working with the release of Sodium.
+    and it will stop working with the release of 3001.
 
     :param name: The name of the package to check
     :param pkgs: A list of packages to check
@@ -567,14 +609,14 @@ def _fix_cask_namespace(name=None, pkgs=None):
 
     show_warning = False
 
-    if name and name.startswith('caskroom/cask/'):
+    if name and name.startswith("caskroom/cask/"):
         show_warning = True
         name = name.replace("caskroom/cask/", "homebrew/cask/")
 
     if pkgs:
         pkgs_ = []
         for pkg in pkgs:
-            if isinstance(pkg, str) and pkg.startswith('caskroom/cask/'):
+            if isinstance(pkg, str) and pkg.startswith("caskroom/cask/"):
                 show_warning = True
                 pkg = pkg.replace("caskroom/cask/", "homebrew/cask/")
                 pkgs_.append(pkg)
@@ -585,9 +627,166 @@ def _fix_cask_namespace(name=None, pkgs=None):
 
     if show_warning:
         salt.utils.versions.warn_until(
-            'Sodium',
-            'The \'caskroom/cask/\' namespace for brew-cask packages '
-            'is deprecated. Use \'homebrew/cask/\' instead.'
+            "Sodium",
+            "The 'caskroom/cask/' namespace for brew-cask packages "
+            "is deprecated. Use 'homebrew/cask/' instead.",
         )
 
     return name, pkgs
+
+
+def hold(name=None, pkgs=None, sources=None, **kwargs):  # pylint: disable=W0613
+    """
+    Set package in 'hold' state, meaning it will not be upgraded.
+
+    .. versionadded:: 3001
+
+    name
+        The name of the package, e.g., 'tmux'
+
+    CLI Example:
+
+     .. code-block:: bash
+
+        salt '*' pkg.hold <package name>
+
+    pkgs
+        A list of packages to hold. Must be passed as a python list.
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' pkg.hold pkgs='["foo", "bar"]'
+    """
+    if not name and not pkgs and not sources:
+        raise SaltInvocationError("One of name, pkgs, or sources must be specified.")
+    if pkgs and sources:
+        raise SaltInvocationError("Only one of pkgs or sources can be specified.")
+
+    targets = []
+    if pkgs:
+        targets.extend(pkgs)
+    elif sources:
+        for source in sources:
+            targets.append(next(iter(source)))
+    else:
+        targets.append(name)
+
+    ret = {}
+    pinned = _list_pinned()
+    installed = list_pkgs()
+    for target in targets:
+        if isinstance(target, dict):
+            target = next(iter(target))
+
+        ret[target] = {"name": target, "changes": {}, "result": False, "comment": ""}
+
+        if target not in installed:
+            ret[target]["comment"] = "Package {0} does not have a state.".format(target)
+        elif target not in pinned:
+            if "test" in __opts__ and __opts__["test"]:
+                ret[target].update(result=None)
+                ret[target]["comment"] = "Package {0} is set to be held.".format(target)
+            else:
+                result = _pin(target)
+                if result:
+                    changes = {"old": "install", "new": "hold"}
+                    ret[target].update(changes=changes, result=True)
+                    ret[target]["comment"] = "Package {0} is now being held.".format(
+                        target
+                    )
+                else:
+                    ret[target].update(result=False)
+                    ret[target]["comment"] = "Unable to hold package {0}.".format(
+                        target
+                    )
+        else:
+            ret[target].update(result=True)
+            ret[target]["comment"] = "Package {0} is already set to be held.".format(
+                target
+            )
+    return ret
+
+
+pin = hold
+
+
+def unhold(name=None, pkgs=None, sources=None, **kwargs):  # pylint: disable=W0613
+    """
+    Set package current in 'hold' state to install state,
+    meaning it will be upgraded.
+
+    .. versionadded:: 3001
+
+    name
+        The name of the package, e.g., 'tmux'
+
+     CLI Example:
+
+     .. code-block:: bash
+
+        salt '*' pkg.unhold <package name>
+
+    pkgs
+        A list of packages to unhold. Must be passed as a python list.
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' pkg.unhold pkgs='["foo", "bar"]'
+    """
+    if not name and not pkgs and not sources:
+        raise SaltInvocationError("One of name, pkgs, or sources must be specified.")
+    if pkgs and sources:
+        raise SaltInvocationError("Only one of pkgs or sources can be specified.")
+
+    targets = []
+    if pkgs:
+        targets.extend(pkgs)
+    elif sources:
+        for source in sources:
+            targets.append(next(iter(source)))
+    else:
+        targets.append(name)
+
+    ret = {}
+    pinned = _list_pinned()
+    installed = list_pkgs()
+    for target in targets:
+        if isinstance(target, dict):
+            target = next(iter(target))
+
+        ret[target] = {"name": target, "changes": {}, "result": False, "comment": ""}
+
+        if target not in installed:
+            ret[target]["comment"] = "Package {0} does not have a state.".format(target)
+        elif target in pinned:
+            if "test" in __opts__ and __opts__["test"]:
+                ret[target].update(result=None)
+                ret[target]["comment"] = "Package {0} is set to be unheld.".format(
+                    target
+                )
+            else:
+                result = _unpin(target)
+                if result:
+                    changes = {"old": "hold", "new": "install"}
+                    ret[target].update(changes=changes, result=True)
+                    ret[target][
+                        "comment"
+                    ] = "Package {0} is no longer being held.".format(target)
+                else:
+                    ret[target].update(result=False)
+                    ret[target]["comment"] = "Unable to unhold package {0}.".format(
+                        target
+                    )
+        else:
+            ret[target].update(result=True)
+            ret[target][
+                "comment"
+            ] = "Package {0} is already set not to be held.".format(target)
+    return ret
+
+
+unpin = unhold
