@@ -1,25 +1,23 @@
 # -*- coding: utf-8 -*-
-
-# Import Python libs
 from __future__ import absolute_import, print_function, unicode_literals
 
-# Import Salt Testing Libs
+import salt.utils.platform
 from tests.support.case import SSHCase
+from tests.support.helpers import slowTest
 from tests.support.unit import skipIf
 
-# Import Salt Libs
-import salt.utils.platform
 
-
-@skipIf(salt.utils.platform.is_windows(), 'salt-ssh not available on Windows')
+@skipIf(salt.utils.platform.is_windows(), "salt-ssh not available on Windows")
 class SSHRawTest(SSHCase):
-    '''
+    """
     testing salt-ssh with raw calls
-    '''
+    """
+
+    @slowTest
     def test_ssh_raw(self):
-        '''
+        """
         test salt-ssh with -r argument
-        '''
-        msg = 'running raw msg'
-        ret = self.run_function('echo {0}'.format(msg), raw=True)
-        self.assertEqual(ret['stdout'], msg + '\n')
+        """
+        msg = "running raw msg"
+        ret = self.run_function("echo {0}".format(msg), raw=True)
+        self.assertEqual(ret["stdout"], msg + "\n")
